--
-- This script contains the ddl to create the engine database.
--
-- @version $Id: create_engine.ddl,v 1.2 2006/03/03 11:32:34 nichele Exp $
--

create table fnbl_user (
  username   varchar(32)  binary not null,
  password   varchar(32)  binary not null,
  email      varchar(50)  binary,
  first_name varchar(255) binary,
  last_name  varchar(255) binary,
  
  constraint pk_user primary key (username)
);

create table fnbl_device (
  id                   varchar(128) binary not null,
  description          varchar(255),
  type                 varchar(255),
  client_nonce         varchar(255),
  server_nonce         varchar(255),
  server_password      varchar(255),
  timezone             varchar(32) ,
  convert_date         char(1)     ,
  charset              varchar(16) ,
  address              varchar(50) ,
  msisdn               varchar(50) ,
  notification_builder varchar(255),
  notification_sender  varchar(255),
  id_caps              integer     ,
  
  constraint pk_device primary key (id)
);

create table fnbl_principal (
  username varchar(32)  binary not null,
  device   varchar(128) binary not null,
  id       integer      not null,
  
  constraint pk_principal primary key (id),
  
  constraint fk_user foreign key (username)
  references fnbl_user (username) on delete cascade on update cascade,

  constraint fk_device foreign key (device)
  references fnbl_device (id) on delete cascade on update cascade  
);

create table fnbl_sync_source (
  uri        varchar(40)  binary not null,
  config     varchar(255) binary not null,
  name       varchar(200) binary not null,
  sourcetype varchar(128) binary not null,
  
  constraint pk_sync_source primary key (uri)
);

create table fnbl_last_sync (
  principal          integer     not null,
  sync_source        varchar(40) binary not null,
  sync_type          integer     not null,
  status             integer,  
  last_anchor_server varchar(20) binary,
  last_anchor_client varchar(20) binary,
  start_sync         bigint,
  end_sync           bigint,
    
  constraint pk_last_sync primary key (principal, sync_source),
  
  constraint fk_principal foreign key (principal) 
  references fnbl_principal (id) on delete cascade on update cascade,

  constraint fk_source foreign key (sync_source) 
  references fnbl_sync_source (uri) on delete cascade on update cascade
);

create table fnbl_client_mapping (
  principal   integer      not null,
  sync_source varchar(40)  binary not null,
  luid        varchar(150) binary not null,
  guid        varchar(150) binary not null,
  last_anchor varchar(20)  binary,  
  
  constraint pk_clientmapping primary key (principal, sync_source, luid, guid),
  
  constraint fk_principal_cm foreign key (principal) 
  references fnbl_principal (id) on delete cascade on update cascade,

  constraint fk_source_cm foreign key (sync_source) 
  references fnbl_sync_source (uri) on delete cascade on update cascade
);

create table fnbl_id (
  idspace varchar(30) binary not null,
  counter integer     not null,
  
  constraint pk_id primary key (idspace)
);

create table fnbl_module (
  id          varchar(128) binary not null,
  name        varchar(200) binary not null,
  description varchar(200) binary,
  
  constraint pk_module primary key (id)
);

create table fnbl_sync_source_type (
  id          varchar(128) binary not null,
  description varchar(200) binary,
  class       varchar(255) binary not null,
  admin_class varchar(255) binary,
  
  constraint pk_sst primary key (id)
);

create table fnbl_module_sync_source_type (
  module     varchar(128) binary not null,
  sourcetype varchar(128) binary not null,
  
  constraint pk_module_sst primary key (module, sourcetype)
);

create table fnbl_connector (
  id          varchar(128) binary not null,
  name        varchar(200) binary not null,
  description varchar(200) binary,
  admin_class varchar(255) binary,
    
  constraint pk_connector primary key (id)
);

create table fnbl_module_connector (
  module    varchar(128) binary not null,
  connector varchar(128) binary not null,
    
  constraint pk_mod_connector primary key (module, connector)
);

create table fnbl_connector_source_type (
  connector  varchar(128) binary not null,
  sourcetype varchar(128) binary not null,
  
  constraint pk_connector_sst primary key (connector, sourcetype)
);

create table fnbl_role (
  role        varchar(128) binary not null,
  description varchar(200) binary not null,
 
  constraint pk_role primary key (role)
);

create table fnbl_user_role (
  username varchar(32)  binary not null,
  role     varchar(128) binary not null,
 
  constraint pk_user_role primary key (username,role),
  
  constraint fk_userrole foreign key (username)
  references fnbl_user (username) on delete cascade on update cascade
);

create index ind_user           on fnbl_user           (username, password);
create index ind_principal      on fnbl_principal      (username, device  );
